@@ -37,43 +37,37 @@ save_to_file({{Section, Key}, Value}, File) ->
     NewFileContents = reverse_and_add_newline(strip_empty_lines(NewLines), []),
     file:write_file(File, NewFileContents).
 
-
-process_file_lines([Section|Rest], SeenLines, Section, Pattern, Key, Value) ->
-    process_section_lines(Rest, [Section|SeenLines], Pattern, Key, Value);
-
-process_file_lines([Line|Rest], SeenLines, Section, Pattern, Key, Value) ->
-    process_file_lines(Rest, [Line|SeenLines], Section, Pattern, Key, Value);
-
+process_file_lines([Section | Rest], SeenLines, Section, Pattern, Key, Value) ->
+    process_section_lines(Rest, [Section | SeenLines], Pattern, Key, Value);
+process_file_lines([Line | Rest], SeenLines, Section, Pattern, Key, Value) ->
+    process_file_lines(Rest, [Line | SeenLines], Section, Pattern, Key, Value);
 process_file_lines([], SeenLines, Section, _Pattern, Key, Value) ->
     % Section wasn't found.  Append it with the option here.
     [Key ++ " = " ++ Value, Section, "" | strip_empty_lines(SeenLines)].
 
-
-process_section_lines([Line|Rest], SeenLines, Pattern, Key, Value) ->
+process_section_lines([Line | Rest], SeenLines, Pattern, Key, Value) ->
     case re:run(Line, Pattern, [{capture, all_but_first}]) of
-    nomatch -> % Found nothing interesting. Move on.
-        process_section_lines(Rest, [Line|SeenLines], Pattern, Key, Value);
-    {match, []} -> % Found another section. Append the option here.
-        lists:reverse(Rest) ++
-        [Line, "", Key ++ " = " ++ Value | strip_empty_lines(SeenLines)];
-    {match, _} -> % Found the option itself. Replace it.
-        lists:reverse(Rest) ++ [Key ++ " = " ++ Value | SeenLines]
+        % Found nothing interesting. Move on.
+        nomatch ->
+            process_section_lines(Rest, [Line | SeenLines], Pattern, Key, Value);
+        % Found another section. Append the option here.
+        {match, []} ->
+            lists:reverse(Rest) ++
+                [Line, "", Key ++ " = " ++ Value | strip_empty_lines(SeenLines)];
+        % Found the option itself. Replace it.
+        {match, _} ->
+            lists:reverse(Rest) ++ [Key ++ " = " ++ Value | SeenLines]
     end;
-
 process_section_lines([], SeenLines, _Pattern, Key, Value) ->
     % Found end of file within the section. Append the option here.
     [Key ++ " = " ++ Value | strip_empty_lines(SeenLines)].
 
-
-reverse_and_add_newline([Line|Rest], Content) ->
+reverse_and_add_newline([Line | Rest], Content) ->
     reverse_and_add_newline(Rest, [Line, "\n", Content]);
-
 reverse_and_add_newline([], Content) ->
     Content.
 
-
 strip_empty_lines(["" | Rest]) ->
     strip_empty_lines(Rest);
-
 strip_empty_lines(All) ->
     All.
