@@ -60,17 +60,19 @@ for_db(DbName) ->
     for_db(DbName, []).
 
 for_db(DbName, Options) ->
-    Shards = try ets:lookup(?SHARDS, DbName) of
-        [] ->
-            load_shards_from_disk(DbName);
-        Else ->
-            gen_server:cast(?MODULE, {cache_hit, DbName}),
-            Else
-    catch error:badarg ->
-        load_shards_from_disk(DbName)
-    end,
+    Shards =
+        try ets:lookup(?SHARDS, DbName) of
+            [] ->
+                load_shards_from_disk(DbName);
+            Else ->
+                gen_server:cast(?MODULE, {cache_hit, DbName}),
+                Else
+        catch
+            error:badarg ->
+                load_shards_from_disk(DbName)
+        end,
     case lists:member(ordered, Options) of
-        true  -> Shards;
+        true -> Shards;
         false -> mem3_util:downcast(Shards)
     end.
 
@@ -92,17 +94,19 @@ for_docid(DbName, DocId, Options) ->
     Conditions = [{'=<', '$1', HashKey}, {'=<', HashKey, '$2'}],
     ShardSpec = {ShardHead, Conditions, ['$_']},
     OrderedShardSpec = {OrderedShardHead, Conditions, ['$_']},
-    Shards = try ets:select(?SHARDS, [ShardSpec, OrderedShardSpec]) of
-        [] ->
-            load_shards_from_disk(DbName, DocId);
-        Else ->
-            gen_server:cast(?MODULE, {cache_hit, DbName}),
-            Else
-    catch error:badarg ->
-        load_shards_from_disk(DbName, DocId)
-    end,
+    Shards =
+        try ets:select(?SHARDS, [ShardSpec, OrderedShardSpec]) of
+            [] ->
+                load_shards_from_disk(DbName, DocId);
+            Else ->
+                gen_server:cast(?MODULE, {cache_hit, DbName}),
+                Else
+        catch
+            error:badarg ->
+                load_shards_from_disk(DbName, DocId)
+        end,
     case lists:member(ordered, Options) of
-        true  -> Shards;
+        true -> Shards;
         false -> mem3_util:downcast(Shards)
     end.
 
@@ -123,35 +127,43 @@ for_shard_range(ShardName) ->
     Conditions = [{'=<', '$1', E}, {'=<', B, '$2'}],
     ShardSpec = {ShardHead, Conditions, ['$_']},
     OrderedShardSpec = {OrderedShardHead, Conditions, ['$_']},
-    Shards = try ets:select(?SHARDS, [ShardSpec, OrderedShardSpec]) of
-        [] ->
-            filter_shards_by_range([B, E], load_shards_from_disk(DbName));
-        Else ->
-            gen_server:cast(?MODULE, {cache_hit, DbName}),
-            Else
-    catch error:badarg ->
-        filter_shards_by_range([B, E], load_shards_from_disk(DbName))
-    end,
+    Shards =
+        try ets:select(?SHARDS, [ShardSpec, OrderedShardSpec]) of
+            [] ->
+                filter_shards_by_range([B, E], load_shards_from_disk(DbName));
+            Else ->
+                gen_server:cast(?MODULE, {cache_hit, DbName}),
+                Else
+        catch
+            error:badarg ->
+                filter_shards_by_range([B, E], load_shards_from_disk(DbName))
+        end,
     mem3_util:downcast(Shards).
 
-
 get(DbName, Node, Range) ->
-    Res = lists:foldl(fun(#shard{node=N, range=R}=S, Acc) ->
-        case {N, R} of
-            {Node, Range} -> [S | Acc];
-            _ -> Acc
-        end
-    end, [], for_db(DbName)),
+    Res = lists:foldl(
+        fun(#shard{node = N, range = R} = S, Acc) ->
+            case {N, R} of
+                {Node, Range} -> [S | Acc];
+                _ -> Acc
+            end
+        end,
+        [],
+        for_db(DbName)
+    ),
     case Res of
         [] -> {error, not_found};
         [Shard] -> {ok, Shard};
-        [_|_] -> {error, duplicates}
+        [_ | _] -> {error, duplicates}
     end.
 
 local(DbName) when is_list(DbName) ->
     local(list_to_binary(DbName));
 local(DbName) ->
-    Pred = fun(#shard{node=Node}) when Node == node() -> true; (_) -> false end,
+    Pred = fun
+        (#shard{node = Node}) when Node == node() -> true;
+        (_) -> false
+    end,
     lists:filter(Pred, for_db(DbName)).
 
 fold(Fun, Acc) ->
@@ -177,11 +189,13 @@ handle_config_change("mem3", "shard_cache_size", SizeList, _, _) ->
 handle_config_change("mem3", "shards_db", _DbName, _, _) ->
     {ok, gen_server:call(?MODULE, shard_db_changed, infinity)};
 handle_config_change("mem3", "shard_write_timeout", Timeout, _, _) ->
-    Timeout = try
-        list_to_integer(Timeout)
-    catch _:_ ->
-        1000
-    end,
+    Timeout =
+        try
+            list_to_integer(Timeout)
+        catch
+            _:_ ->
+                1000
+        end,
     {ok, gen_server:call(?MODULE, {set_write_timeout, Timeout})};
 handle_config_change(_, _, _, _, _) ->
     {ok, nil}.
@@ -197,7 +211,7 @@ init([]) ->
         bag,
         public,
         named_table,
-        {keypos,#shard.dbname},
+        {keypos, #shard.dbname},
         {read_concurrency, true}
     ]),
     ets:new(?DBS, [set, protected, named_table]),
@@ -206,6 +220,8 @@ init([]) ->
     ok = config:listen_for_changes(?MODULE, nil),
     SizeList = config:get("mem3", "shard_cache_size", "25000"),
     WriteTimeout = config:get_integer("mem3", "shard_write_timeout", 1000),
+    DbName = mem3_sync:shards_db(),
+    ioq:set_io_priority({system, DbName}),
     UpdateSeq = get_update_seq(),
     {ok, #st{
         max_size = list_to_integer(SizeList),
@@ -216,7 +232,7 @@ init([]) ->
     }}.
 
 handle_call({set_max_size, Size}, _From, St) ->
-    {reply, ok, cache_free(St#st{max_size=Size})};
+    {reply, ok, cache_free(St#st{max_size = Size})};
 handle_call(shard_db_changed, _From, St) ->
     exit(St#st.changes_pid, shard_db_changed),
     {reply, ok, St};
@@ -237,13 +253,14 @@ handle_cast({cache_insert, DbName, Writer, UpdateSeq}, St) ->
     % to think of when a _dbs db doesn't change. If it used
     % `=<` it would be impossible to insert anything into
     % the cache.
-    NewSt = case UpdateSeq < St#st.update_seq of
-        true ->
-            Writer ! cancel,
-            St;
-        false ->
-            cache_free(cache_insert(St, DbName, Writer, St#st.write_timeout))
-    end,
+    NewSt =
+        case UpdateSeq < St#st.update_seq of
+            true ->
+                Writer ! cancel,
+                St;
+            false ->
+                cache_free(cache_insert(St, DbName, Writer, St#st.write_timeout))
+        end,
     {noreply, NewSt};
 handle_cast({cache_remove, DbName}, St) ->
     couch_stats:increment_counter([mem3, shard_cache, eviction]),
@@ -258,18 +275,19 @@ handle_cast({cache_remove_change, DbName, UpdateSeq}, St) ->
 handle_cast(_Msg, St) ->
     {noreply, St}.
 
-handle_info({'DOWN', _, _, Pid, Reason}, #st{changes_pid=Pid}=St) ->
-    {NewSt, Seq} = case Reason of
-        {seq, EndSeq} ->
-            {St, EndSeq};
-        shard_db_changed ->
-            {cache_clear(St), get_update_seq()};
-        _ ->
-            couch_log:notice("~p changes listener died ~p", [?MODULE, Reason]),
-            {St, get_update_seq()}
-    end,
+handle_info({'DOWN', _, _, Pid, Reason}, #st{changes_pid = Pid} = St) ->
+    {NewSt, Seq} =
+        case Reason of
+            {seq, EndSeq} ->
+                {St, EndSeq};
+            shard_db_changed ->
+                {cache_clear(St), get_update_seq()};
+            _ ->
+                couch_log:notice("~p changes listener died ~p", [?MODULE, Reason]),
+                {St, get_update_seq()}
+        end,
     erlang:send_after(5000, self(), {start_listener, Seq}),
-    {noreply, NewSt#st{changes_pid=undefined}};
+    {noreply, NewSt#st{changes_pid = undefined}};
 handle_info({start_listener, Seq}, St) ->
     {noreply, St#st{
         changes_pid = start_changes_listener(Seq)
@@ -280,11 +298,11 @@ handle_info(restart_config_listener, State) ->
 handle_info(_Msg, St) ->
     {noreply, St}.
 
-terminate(_Reason, #st{changes_pid=Pid}) ->
+terminate(_Reason, #st{changes_pid = Pid}) ->
     exit(Pid, kill),
     ok.
 
-code_change(_OldVsn, #st{}=St, _Extra) ->
+code_change(_OldVsn, #st{} = St, _Extra) ->
     {ok, St}.
 
 %% internal functions
@@ -304,10 +322,10 @@ start_changes_listener(SinceSeq) ->
     end),
     Pid.
 
-fold_fun(#full_doc_info{}=FDI, Acc) ->
+fold_fun(#full_doc_info{} = FDI, Acc) ->
     DI = couch_doc:to_doc_info(FDI),
     fold_fun(DI, Acc);
-fold_fun(#doc_info{}=DI, {Db, UFun, UAcc}) ->
+fold_fun(#doc_info{} = DI, {Db, UFun, UAcc}) ->
     case couch_db:open_doc(Db, DI, [ejson_body, conflicts]) of
         {ok, Doc} ->
             {Props} = Doc#doc.body,
@@ -325,7 +343,9 @@ get_update_seq() ->
     Seq.
 
 listen_for_changes(Since) ->
-    {ok, Db} = mem3_util:ensure_exists(mem3_sync:shards_db()),
+    DbName = mem3_sync:shards_db(),
+    ioq:set_io_priority({system, DbName}),
+    {ok, Db} = mem3_util:ensure_exists(DbName),
     Args = #changes_args{
         feed = "continuous",
         since = Since,
@@ -342,27 +362,37 @@ changes_callback({stop, EndSeq}, _) ->
 changes_callback({change, {Change}, _}, _) ->
     DbName = couch_util:get_value(<<"id">>, Change),
     Seq = couch_util:get_value(<<"seq">>, Change),
-    case DbName of <<"_design/", _/binary>> -> ok; _Else ->
-        case mem3_util:is_deleted(Change) of
-        true ->
-            gen_server:cast(?MODULE, {cache_remove_change, DbName, Seq});
-        false ->
-            case couch_util:get_value(doc, Change) of
-            {error, Reason} ->
-                couch_log:error("missing partition table for ~s: ~p",
-                    [DbName, Reason]);
-            {Doc} ->
-                Shards = mem3_util:build_ordered_shards(DbName, Doc),
-                IdleTimeout = config:get_integer(
-                        "mem3", "writer_idle_timeout", 30000),
-                Writer = spawn_shard_writer(DbName, Shards, IdleTimeout),
-                ets:insert(?OPENERS, {DbName, Writer}),
-                Msg = {cache_insert_change, DbName, Writer, Seq},
-                gen_server:cast(?MODULE, Msg),
-                [create_if_missing(mem3:name(S)) || S
-                    <- Shards, mem3:node(S) =:= node()]
+    case DbName of
+        <<"_design/", _/binary>> ->
+            ok;
+        _Else ->
+            case mem3_util:is_deleted(Change) of
+                true ->
+                    gen_server:cast(?MODULE, {cache_remove_change, DbName, Seq});
+                false ->
+                    case couch_util:get_value(doc, Change) of
+                        {error, Reason} ->
+                            couch_log:error(
+                                "missing partition table for ~s: ~p",
+                                [DbName, Reason]
+                            );
+                        {Doc} ->
+                            Shards = mem3_util:build_ordered_shards(DbName, Doc),
+                            IdleTimeout = config:get_integer(
+                                "mem3", "writer_idle_timeout", 30000
+                            ),
+                            Writer = spawn_shard_writer(DbName, Shards, IdleTimeout),
+                            ets:insert(?OPENERS, {DbName, Writer}),
+                            Msg = {cache_insert_change, DbName, Writer, Seq},
+                            gen_server:cast(?MODULE, Msg),
+                            [
+                                create_if_missing(mem3:name(S))
+                             || S <-
+                                    Shards,
+                                mem3:node(S) =:= node()
+                            ]
+                    end
             end
-        end
     end,
     {ok, Seq};
 changes_callback(timeout, _) ->
@@ -379,28 +409,28 @@ load_shards_from_disk(DbName) when is_binary(DbName) ->
 
 load_shards_from_db(ShardDb, DbName) ->
     case couch_db:open_doc(ShardDb, DbName, [ejson_body]) of
-    {ok, #doc{body = {Props}}} ->
-        Seq = couch_db:get_update_seq(ShardDb),
-        Shards = mem3_util:build_ordered_shards(DbName, Props),
-        IdleTimeout = config:get_integer("mem3", "writer_idle_timeout", 30000),
-        case maybe_spawn_shard_writer(DbName, Shards, IdleTimeout) of
-            Writer when is_pid(Writer) ->
-                case ets:insert_new(?OPENERS, {DbName, Writer}) of
-                    true ->
-                        Msg = {cache_insert, DbName, Writer, Seq},
-                        gen_server:cast(?MODULE, Msg);
-                    false ->
-                        Writer ! cancel
-                end;
-            ignore ->
-                ok
-        end,
-        Shards;
-    {not_found, _} ->
-        erlang:error(database_does_not_exist, ?b2l(DbName))
+        {ok, #doc{body = {Props}}} ->
+            Seq = couch_db:get_update_seq(ShardDb),
+            Shards = mem3_util:build_ordered_shards(DbName, Props),
+            IdleTimeout = config:get_integer("mem3", "writer_idle_timeout", 30000),
+            case maybe_spawn_shard_writer(DbName, Shards, IdleTimeout) of
+                Writer when is_pid(Writer) ->
+                    case ets:insert_new(?OPENERS, {DbName, Writer}) of
+                        true ->
+                            Msg = {cache_insert, DbName, Writer, Seq},
+                            gen_server:cast(?MODULE, Msg);
+                        false ->
+                            Writer ! cancel
+                    end;
+                ignore ->
+                    ok
+            end,
+            Shards;
+        {not_found, _} ->
+            erlang:error(database_does_not_exist, ?b2l(DbName))
     end.
 
-load_shards_from_disk(DbName, DocId)->
+load_shards_from_disk(DbName, DocId) ->
     Shards = load_shards_from_disk(DbName),
     HashKey = mem3_hash:calculate(hd(Shards), DocId),
     [S || S <- Shards, in_range(S, HashKey)].
@@ -416,15 +446,17 @@ create_if_missing(ShardName) ->
         false ->
             Options = opts_for_db(ShardName),
             case couch_server:create(ShardName, [?ADMIN_CTX] ++ Options) of
-            {ok, Db} ->
-                couch_db:close(Db);
-            Error ->
-                couch_log:error("~p tried to create ~s, got ~p",
-                    [?MODULE, ShardName, Error])
+                {ok, Db} ->
+                    couch_db:close(Db);
+                Error ->
+                    couch_log:error(
+                        "~p tried to create ~s, got ~p",
+                        [?MODULE, ShardName, Error]
+                    )
             end
     end.
 
-cache_insert(#st{cur_size=Cur}=St, DbName, Writer, Timeout) ->
+cache_insert(#st{cur_size = Cur} = St, DbName, Writer, Timeout) ->
     NewATime = couch_util:unique_monotonic_integer(),
     true = ets:delete(?SHARDS, DbName),
     flush_write(DbName, Writer, Timeout),
@@ -437,16 +469,16 @@ cache_insert(#st{cur_size=Cur}=St, DbName, Writer, Timeout) ->
         [] ->
             true = ets:insert(?ATIMES, {NewATime, DbName}),
             true = ets:insert(?DBS, {DbName, NewATime}),
-            St#st{cur_size=Cur + 1}
+            St#st{cur_size = Cur + 1}
     end.
 
-cache_remove(#st{cur_size=Cur}=St, DbName) ->
+cache_remove(#st{cur_size = Cur} = St, DbName) ->
     true = ets:delete(?SHARDS, DbName),
     case ets:lookup(?DBS, DbName) of
         [{DbName, ATime}] ->
             true = ets:delete(?DBS, DbName),
             true = ets:delete(?ATIMES, ATime),
-            St#st{cur_size=Cur-1};
+            St#st{cur_size = Cur - 1};
         [] ->
             St
     end.
@@ -462,13 +494,13 @@ cache_hit(DbName) ->
             ok
     end.
 
-cache_free(#st{max_size=Max, cur_size=Cur}=St) when Max =< Cur ->
+cache_free(#st{max_size = Max, cur_size = Cur} = St) when Max =< Cur ->
     ATime = ets:first(?ATIMES),
     [{ATime, DbName}] = ets:lookup(?ATIMES, ATime),
     true = ets:delete(?ATIMES, ATime),
     true = ets:delete(?DBS, DbName),
     true = ets:delete(?SHARDS, DbName),
-    cache_free(St#st{cur_size=Cur-1});
+    cache_free(St#st{cur_size = Cur - 1});
 cache_free(St) ->
     St.
 
@@ -476,7 +508,7 @@ cache_clear(St) ->
     true = ets:delete_all_objects(?DBS),
     true = ets:delete_all_objects(?SHARDS),
     true = ets:delete_all_objects(?ATIMES),
-    St#st{cur_size=0}.
+    St#st{cur_size = 0}.
 
 maybe_spawn_shard_writer(DbName, Shards, IdleTimeout) ->
     case ets:member(?OPENERS, DbName) of
@@ -515,13 +547,14 @@ flush_write(DbName, Writer, WriteTimeout) ->
         erlang:exit({mem3_shards_write_timeout, DbName})
     end.
 
-
-filter_shards_by_range(Range, Shards)->
-    lists:filter(fun
-        (#ordered_shard{range = R}) -> mem3_util:range_overlap(Range, R);
-        (#shard{range = R}) -> mem3_util:range_overlap(Range, R)
-    end, Shards).
-
+filter_shards_by_range(Range, Shards) ->
+    lists:filter(
+        fun
+            (#ordered_shard{range = R}) -> mem3_util:range_overlap(Range, R);
+            (#shard{range = R}) -> mem3_util:range_overlap(Range, R)
+        end,
+        Shards
+    ).
 
 -ifdef(TEST).
 
@@ -530,7 +563,6 @@ filter_shards_by_range(Range, Shards)->
 -define(DB, <<"eunit_db_name">>).
 -define(INFINITY, 99999999).
 
-
 mem3_shards_test_() ->
     {
         setup,
@@ -555,7 +587,6 @@ mem3_shards_test_() ->
         }
     }.
 
-
 setup_all() ->
     ets:new(?SHARDS, [bag, public, named_table, {keypos, #shard.dbname}]),
     ets:new(?OPENERS, [bag, public, named_table]),
@@ -564,7 +595,6 @@ setup_all() ->
     meck:expect(config, get, ["mem3", "shards_db", '_'], "_dbs"),
     ok.
 
-
 teardown_all(_) ->
     meck:unload(),
     ets:delete(?ATIMES),
@@ -572,18 +602,15 @@ teardown_all(_) ->
     ets:delete(?OPENERS),
     ets:delete(?SHARDS).
 
-
 setup() ->
     ets:delete_all_objects(?ATIMES),
     ets:delete_all_objects(?DBS),
     ets:delete_all_objects(?OPENERS),
     ets:delete_all_objects(?SHARDS).
 
-
 teardown(_) ->
     ok.
 
-
 t_maybe_spawn_shard_writer_already_exists() ->
     ?_test(begin
         ets:insert(?OPENERS, {?DB, self()}),
@@ -592,7 +619,6 @@ t_maybe_spawn_shard_writer_already_exists() ->
         ?assertEqual(ignore, WRes)
     end).
 
-
 t_maybe_spawn_shard_writer_new() ->
     ?_test(begin
         Shards = mock_shards(),
@@ -605,7 +631,6 @@ t_maybe_spawn_shard_writer_new() ->
         ?assertEqual(Shards, ets:tab2list(?SHARDS))
     end).
 
-
 t_flush_writer_exists_normal() ->
     ?_test(begin
         Shards = mock_shards(),
@@ -614,24 +639,29 @@ t_flush_writer_exists_normal() ->
         ?assertEqual(Shards, ets:tab2list(?SHARDS))
     end).
 
-
 t_flush_writer_times_out() ->
     ?_test(begin
-        WPid = spawn(fun() -> receive will_never_receive_this -> ok end end),
+        WPid = spawn(fun() ->
+            receive
+                will_never_receive_this -> ok
+            end
+        end),
         Error = {mem3_shards_write_timeout, ?DB},
         ?assertExit(Error, flush_write(?DB, WPid, 100)),
         exit(WPid, kill)
     end).
 
-
 t_flush_writer_crashes() ->
     ?_test(begin
-        WPid = spawn(fun() -> receive write -> exit('kapow!') end end),
+        WPid = spawn(fun() ->
+            receive
+                write -> exit('kapow!')
+            end
+        end),
         Error = {mem3_shards_bad_write, 'kapow!'},
         ?assertExit(Error, flush_write(?DB, WPid, 1000))
     end).
 
-
 t_writer_deletes_itself_when_done() ->
     ?_test(begin
         Shards = mock_shards(),
@@ -644,14 +674,14 @@ t_writer_deletes_itself_when_done() ->
         ?assertEqual([], ets:tab2list(?OPENERS))
     end).
 
-
 t_writer_does_not_delete_other_writers_for_same_shard() ->
     ?_test(begin
         Shards = mock_shards(),
         WPid = spawn_link_mock_writer(?DB, Shards, ?INFINITY),
         WRef = erlang:monitor(process, WPid),
         ets:insert(?OPENERS, {?DB, WPid}),
-        ets:insert(?OPENERS, {?DB, self()}),  % should not be deleted
+        % should not be deleted
+        ets:insert(?OPENERS, {?DB, self()}),
         WPid ! write,
         ?assertEqual(normal, wait_writer_result(WRef)),
         ?assertEqual(Shards, ets:tab2list(?SHARDS)),
@@ -659,21 +689,22 @@ t_writer_does_not_delete_other_writers_for_same_shard() ->
         ?assertEqual([{?DB, self()}], ets:tab2list(?OPENERS))
     end).
 
-
 t_spawn_writer_in_load_shards_from_db() ->
     ?_test(begin
         meck:expect(couch_db, open_doc, 3, {ok, #doc{body = {[]}}}),
         meck:expect(couch_db, get_update_seq, 1, 1),
         meck:expect(mem3_util, build_ordered_shards, 2, mock_shards()),
-        erlang:register(?MODULE, self()), % register to get cache_insert cast
+        % register to get cache_insert cast
+        erlang:register(?MODULE, self()),
         load_shards_from_db(test_util:fake_db([{name, <<"testdb">>}]), ?DB),
         meck:validate(couch_db),
         meck:validate(mem3_util),
-        Cast = receive
+        Cast =
+            receive
                 {'$gen_cast', Msg} -> Msg
             after 1000 ->
                 timeout
-        end,
+            end,
         ?assertMatch({cache_insert, ?DB, Pid, 1} when is_pid(Pid), Cast),
         {cache_insert, _, WPid, _} = Cast,
         exit(WPid, kill),
@@ -682,7 +713,6 @@ t_spawn_writer_in_load_shards_from_db() ->
         meck:unload(mem3_util)
     end).
 
-
 t_cache_insert_takes_new_update() ->
     ?_test(begin
         Shards = mock_shards(),
@@ -694,7 +724,6 @@ t_cache_insert_takes_new_update() ->
         ?assertEqual([], ets:tab2list(?OPENERS))
     end).
 
-
 t_cache_insert_ignores_stale_update_and_kills_worker() ->
     ?_test(begin
         Shards = mock_shards(),
@@ -708,7 +737,6 @@ t_cache_insert_ignores_stale_update_and_kills_worker() ->
         ?assertEqual([], ets:tab2list(?OPENERS))
     end).
 
-
 mock_state(UpdateSeq) ->
     #st{
         update_seq = UpdateSeq,
@@ -716,44 +744,40 @@ mock_state(UpdateSeq) ->
         write_timeout = 1000
     }.
 
-
 mock_shards() ->
     [
         #ordered_shard{
             name = <<"testshardname">>,
             node = node(),
             dbname = ?DB,
-            range = [0,1],
+            range = [0, 1],
             order = 1
         }
     ].
 
-
 wait_writer_result(WRef) ->
     receive
         {'DOWN', WRef, _, _, Result} ->
             Result
-        after 1000 ->
-            timeout
+    after 1000 ->
+        timeout
     end.
 
-
 spawn_link_mock_writer(Db, Shards, Timeout) ->
     erlang:spawn_link(fun() -> shard_writer(Db, Shards, Timeout) end).
 
-
-
-mem3_shards_changes_test_() -> {
-    "Test mem3_shards changes listener",
+mem3_shards_changes_test_() ->
     {
-        setup,
-        fun test_util:start_couch/0, fun test_util:stop_couch/1,
-        [
-            fun should_kill_changes_listener_on_shutdown/0
-        ]
-    }
-}.
-
+        "Test mem3_shards changes listener",
+        {
+            setup,
+            fun test_util:start_couch/0,
+            fun test_util:stop_couch/1,
+            [
+                fun should_kill_changes_listener_on_shutdown/0
+            ]
+        }
+    }.
 
 should_kill_changes_listener_on_shutdown() ->
     {ok, Pid} = ?MODULE:start_link(),
@@ -761,7 +785,8 @@ should_kill_changes_listener_on_shutdown() ->
     ?assert(is_process_alive(ChangesPid)),
     true = erlang:unlink(Pid),
     true = test_util:stop_sync_throw(
-        ChangesPid, fun() -> exit(Pid, shutdown) end, wait_timeout),
+        ChangesPid, fun() -> exit(Pid, shutdown) end, wait_timeout
+    ),
     ?assertNot(is_process_alive(ChangesPid)),
     exit(Pid, shutdown).
 
